@@ -1,5 +1,5 @@
 from .base import ReadOnlyObjectItem, CRUDObjectItem, CRObjectItem
-from .mixin import PayURLMixin, RefundCaptureVoidObjectItemMixin, CardShareObjectItemMixin, ChargeObjectItemMixin, StartPauseStopActiveObjectItemMixin
+from .mixin import PayURLMixin, RefundCaptureVoidObjectItemMixin, CardShareObjectItemMixin, ChargeObjectItemMixin, StartPauseStopActiveObjectItemMixin, IbanObjectItemMixin
 
 
 class Product(CRUDObjectItem):
@@ -65,6 +65,27 @@ class Sale(RefundCaptureVoidObjectItemMixin, ReadOnlyObjectItem):
     pass
 
 
+class Client(IbanObjectItemMixin, CRObjectItem):
+    """
+    Client object
+    """
+    pass
+
+
+class Wallet(CRObjectItem):
+    """
+    Wallet object
+    """
+    pass
+
+
+class Transfer(CRObjectItem):
+    """
+    Wallet object
+    """
+    pass
+
+
 class Currency(ReadOnlyObjectItem):
     """
     Currency object
