@@ -1,7 +1,7 @@
-from .mixin import RefundCaptureVoidResourceMixin, CardShareResourceMixin, ChargeResourceMixin, StartPauseStopActiveResourceMixin
+from .mixin import RefundCaptureVoidResourceMixin, CardShareResourceMixin, ChargeResourceMixin, StartPauseStopActiveResourceMixin, IbanResourceMixin
 from .base import DetailOnlyResource, ReadOnlyResource, CRResource, CRUDResource
-from .objects import Product, Plan, Tax, Shipping, Coupon, Transaction, Subscription, Authorization, Sale, Currency, \
-    Gateway, PayData
+from .objects import Product, Plan, Tax, Shipping, Coupon, Transaction, Subscription, Authorization, Sale, Client, Wallet, \
+    Transfer, Currency, Gateway, PayData
 
 
 class ProductResource(CRUDResource):
@@ -76,6 +76,30 @@ class SaleResource(RefundCaptureVoidResourceMixin, ReadOnlyResource):
     OBJECT_ITEM_CLASS = Sale
 
 
+class ClientResource(IbanResourceMixin, CRResource):
+    """
+    Client resource
+    """
+    PATH = '/client/'
+    OBJECT_ITEM_CLASS = Client
+
+
+class WalletResource(CRResource):
+    """
+    Wallet resource
+    """
+    PATH = '/wallet/'
+    OBJECT_ITEM_CLASS = Wallet
+
+
+class TransferResource(CRResource):
+    """
+    Transfer resource
+    """
+    PATH = '/transfer/'
+    OBJECT_ITEM_CLASS = Transfer
+
+
 class CurrencyResource(ReadOnlyResource):
     """
     Currency resource
